==> glirc-2.40-10-x86_64.pkg.tar.zst: usr/share/haskell/register/glirc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 glirc
version:              2.40
visibility:           public
id:                   glirc-2.40-LF1mvn7Lv9559AvGMujKWS
key:                  glirc-2.40-LF1mvn7Lv9559AvGMujKWS
license:              ISC
copyright:            2016-2019 Eric Mertens
maintainer:           emertens@gmail.com
author:               Eric Mertens
homepage:             https://github.com/glguy/irc-core
synopsis:             Console IRC client
description:
    Console IRC client

    glirc is a console IRC client with an emphasis on providing
    dynamic views into the model of your IRC connections.

    <https://github.com/glguy/irc-core/wiki Documentation Wiki>

category:             Network
abi:                  8cc16dc36423c299b568bd8858aab117
exposed:              True
exposed-modules:
    Client.Authentication.Ecdh Client.Authentication.Ecdsa
    Client.Authentication.Scram Client.CApi Client.CApi.Exports
    Client.CApi.Types Client.Commands Client.Commands.Arguments.Parser
    Client.Commands.Arguments.Renderer Client.Commands.Arguments.Spec
    Client.Commands.Certificate Client.Commands.Channel
    Client.Commands.Chat Client.Commands.Connection
    Client.Commands.Exec Client.Commands.Interpolation
    Client.Commands.Operator Client.Commands.Queries
    Client.Commands.Recognizer Client.Commands.TabCompletion
    Client.Commands.Toggles Client.Commands.Types
    Client.Commands.Window Client.Commands.WordCompletion
    Client.Commands.ZNC Client.Configuration
    Client.Configuration.Colors Client.Configuration.Macros
    Client.Configuration.Notifications
    Client.Configuration.ServerSettings Client.Configuration.Sts
    Client.EventLoop Client.EventLoop.Actions Client.EventLoop.Errors
    Client.EventLoop.Network Client.Hook Client.Hook.DroneBLRelay
    Client.Hook.Matterbridge Client.Hook.Snotice
    Client.Hook.Znc.Buffextras Client.Hooks Client.Image
    Client.Image.Layout Client.Image.LineWrap Client.Image.Message
    Client.Image.MircFormatting Client.Image.PackedImage
    Client.Image.Palette Client.Image.StatusLine Client.Image.Textbox
    Client.Log Client.Mask Client.Message Client.Network.Async
    Client.Network.Connect Client.Options Client.State
    Client.State.Channel Client.State.EditBox
    Client.State.EditBox.Content Client.State.Extensions
    Client.State.Focus Client.State.Network Client.State.Url
    Client.State.Window Client.UserHost Client.View Client.View.Cert
    Client.View.ChannelInfo Client.View.ChannelList
    Client.View.Digraphs Client.View.Help Client.View.IgnoreList
    Client.View.KeyMap Client.View.MaskList Client.View.Mentions
    Client.View.Messages Client.View.Palette Client.View.RtsStats
    Client.View.UrlSelection Client.View.UserList Client.View.Who
    Client.View.Windows Client.WhoReply

hidden-modules:
    ContextFilter DigraphQuote Digraphs LensUtils RtsStats StrQuote
    StrictUnit Paths_glirc Build_glirc

import-dirs:          /usr/lib/ghc-9.2.8/site-local/glirc-2.40
library-dirs:         /usr/lib/ghc-9.2.8/site-local/glirc-2.40
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/glirc
hs-libraries:         HSglirc-2.40-LF1mvn7Lv9559AvGMujKWS
include-dirs:         /usr/lib/ghc-9.2.8/site-local/glirc-2.40/include
includes:             include/glirc-api.h
depends:
    HsOpenSSL-0.11.7.9-PptsFfDVCuG9RAhEnh5qi
    async-2.2.5-cqcrAyJc5KBpUy7cUuVT7
    attoparsec-0.14.4-HI028cZ2WwJ53VFJd3R6KF base-4.16.4.0
    base64-bytestring-1.2.1.0-10uzYZsf0KVKU2D9qeaVY8
    bytestring-0.11.4.0 config-schema-1.3.0.0-CbGImSbpMD2LNfqUgo35oy
    config-value-0.8.3-8yCRuGm4wH18pEPQuVa8HA containers-0.6.5.1
    curve25519-0.2.8-K0FTHyGmY4pGT12uFeKq0m directory-1.3.6.2
    filepath-1.4.2.2 free-5.2-Ga01Ob8D3vGBIfWx2led3c
    githash-0.1.6.3-3TpZGfugT3Y4QmfMghhzl9
    hashable-1.4.4.0-7BSyPsBurXt9vEzyIgxmkb
    hookup-0.8-9vVRWJeMH6v1nd7kTe1pM5
    irc-core-2.12-7WyFjsiLERF2vTkSgrgl0O
    kan-extensions-5.2.6-JOAFojy7RipAGAPlyeif9j
    lens-5.2.3-26QJUQUcTRlAVm0AF51AC3
    network-3.1.4.0-3UsgZVPxzJR3pZOZAOsXvy
    psqueues-0.2.8.0-JfAhkby4caW9NElqPWQl83
    random-1.2.1.2-F9rVStWFtZE3PBeMKQuK89
    regex-tdfa-1.3.2.2-DLHXQcbmHoIEQ3jvJUiJ2D
    semigroupoids-5.3.7-BpiOw3WiZkODZTOq2Gwk18
    split-0.2.5-fPWkUXEXZHvXnPhPWCGf stm-2.5.0.2
    template-haskell-2.18.0.0 text-1.2.5.0 time-1.11.1.1
    transformers-0.5.6.2 typed-process-0.2.11.1-2iXUeWqQH1Y5r1Uyfifprh
    unix-2.7.2.2 unordered-containers-0.2.20-1oXBHIneMBm69TPTD2tYrr
    vector-0.13.1.0-fp7g3DnwvJ21p5JSIbLxP
    vty-6.1-3vzfBo6frVrCDk3sucuAxw

haddock-interfaces:   /usr/share/doc/glirc/html/glirc.haddock
haddock-html:         /usr/share/doc/glirc/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> glirc-2.40-11-x86_64.pkg.tar.zst: usr/share/haskell/register/glirc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 glirc
version:              2.40
visibility:           public
id:                   glirc-2.40-KT5xitsHyYaHpf8CjcDRt5
key:                  glirc-2.40-KT5xitsHyYaHpf8CjcDRt5
license:              ISC
copyright:            2016-2019 Eric Mertens
maintainer:           emertens@gmail.com
author:               Eric Mertens
homepage:             https://github.com/glguy/irc-core
synopsis:             Console IRC client
description:
    Console IRC client

    glirc is a console IRC client with an emphasis on providing
    dynamic views into the model of your IRC connections.

    <https://github.com/glguy/irc-core/wiki Documentation Wiki>

category:             Network
abi:                  04471d34949f0fcf95e36a605a0338bb
exposed:              True
exposed-modules:
    Client.Authentication.Ecdh Client.Authentication.Ecdsa
    Client.Authentication.Scram Client.CApi Client.CApi.Exports
    Client.CApi.Types Client.Commands Client.Commands.Arguments.Parser
    Client.Commands.Arguments.Renderer Client.Commands.Arguments.Spec
    Client.Commands.Certificate Client.Commands.Channel
    Client.Commands.Chat Client.Commands.Connection
    Client.Commands.Exec Client.Commands.Interpolation
    Client.Commands.Operator Client.Commands.Queries
    Client.Commands.Recognizer Client.Commands.TabCompletion
    Client.Commands.Toggles Client.Commands.Types
    Client.Commands.Window Client.Commands.WordCompletion
    Client.Commands.ZNC Client.Configuration
    Client.Configuration.Colors Client.Configuration.Macros
    Client.Configuration.Notifications
    Client.Configuration.ServerSettings Client.Configuration.Sts
    Client.EventLoop Client.EventLoop.Actions Client.EventLoop.Errors
    Client.EventLoop.Network Client.Hook Client.Hook.DroneBLRelay
    Client.Hook.Matterbridge Client.Hook.Snotice
    Client.Hook.Znc.Buffextras Client.Hooks Client.Image
    Client.Image.Layout Client.Image.LineWrap Client.Image.Message
    Client.Image.MircFormatting Client.Image.PackedImage
    Client.Image.Palette Client.Image.StatusLine Client.Image.Textbox
    Client.Log Client.Mask Client.Message Client.Network.Async
    Client.Network.Connect Client.Options Client.State
    Client.State.Channel Client.State.EditBox
    Client.State.EditBox.Content Client.State.Extensions
    Client.State.Focus Client.State.Network Client.State.Url
    Client.State.Window Client.UserHost Client.View Client.View.Cert
    Client.View.ChannelInfo Client.View.ChannelList
    Client.View.Digraphs Client.View.Help Client.View.IgnoreList
    Client.View.KeyMap Client.View.MaskList Client.View.Mentions
    Client.View.Messages Client.View.Palette Client.View.RtsStats
    Client.View.UrlSelection Client.View.UserList Client.View.Who
    Client.View.Windows Client.WhoReply

hidden-modules:
    ContextFilter DigraphQuote Digraphs LensUtils RtsStats StrQuote
    StrictUnit Paths_glirc Build_glirc

import-dirs:          /usr/lib/ghc-9.2.8/site-local/glirc-2.40
library-dirs:         /usr/lib/ghc-9.2.8/site-local/glirc-2.40
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/glirc
hs-libraries:         HSglirc-2.40-KT5xitsHyYaHpf8CjcDRt5
include-dirs:         /usr/lib/ghc-9.2.8/site-local/glirc-2.40/include
includes:             include/glirc-api.h
depends:
    HsOpenSSL-0.11.7.9-PptsFfDVCuG9RAhEnh5qi
    async-2.2.5-cqcrAyJc5KBpUy7cUuVT7
    attoparsec-0.14.4-HI028cZ2WwJ53VFJd3R6KF base-4.16.4.0
    base64-bytestring-1.2.1.0-10uzYZsf0KVKU2D9qeaVY8
    bytestring-0.11.4.0 config-schema-1.3.0.0-9sa29kTxaypBs5SmqF4d8x
    config-value-0.8.3-8yCRuGm4wH18pEPQuVa8HA containers-0.6.5.1
    curve25519-0.2.8-K0FTHyGmY4pGT12uFeKq0m directory-1.3.6.2
    filepath-1.4.2.2 free-5.2-I49bMKgDBK7LoTwjaObXf0
    githash-0.1.6.3-3TpZGfugT3Y4QmfMghhzl9
    hashable-1.4.4.0-7BSyPsBurXt9vEzyIgxmkb
    hookup-0.8-9vVRWJeMH6v1nd7kTe1pM5
    irc-core-2.12-7WyFjsiLERF2vTkSgrgl0O
    kan-extensions-5.2.6-CWXkGXi2hhi9b3WWA7Mt56
    lens-5.2.3-E9qTqYswc1XFU8czBYRRKh
    network-3.1.4.0-3UsgZVPxzJR3pZOZAOsXvy
    psqueues-0.2.8.0-JfAhkby4caW9NElqPWQl83
    random-1.2.1.2-F9rVStWFtZE3PBeMKQuK89
    regex-tdfa-1.3.2.2-DLHXQcbmHoIEQ3jvJUiJ2D
    semigroupoids-6.0.0.1-DtySamiEiX761Pjjwrbwht
    split-0.2.5-fPWkUXEXZHvXnPhPWCGf stm-2.5.0.2
    template-haskell-2.18.0.0 text-1.2.5.0 time-1.11.1.1
    transformers-0.5.6.2 typed-process-0.2.11.1-2iXUeWqQH1Y5r1Uyfifprh
    unix-2.7.2.2 unordered-containers-0.2.20-1oXBHIneMBm69TPTD2tYrr
    vector-0.13.1.0-fp7g3DnwvJ21p5JSIbLxP
    vty-6.1-3vzfBo6frVrCDk3sucuAxw

haddock-interfaces:   /usr/share/doc/glirc/html/glirc.haddock
haddock-html:         /usr/share/doc/glirc/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
